{% templatetag openblock %} extends "bigbuild/base.html" {% templatetag closeblock %}

{% templatetag openblock %} block container {% templatetag closeblock %}
<article class="container">
    <header class="center">
        <h1>{% templatetag openvariable %} object.headline {% templatetag closevariable %}</h1>
        <p class="description">{% templatetag openvariable %} object.description|safe {% templatetag closevariable %}</p>
        <p class="byline">
            By <span class="author">{% templatetag openvariable %} object.byline|safe {% templatetag closevariable %}</span>
        </p>
        <p class="dateline">
            <time datetime="{% templatetag openvariable %} object.pub_date|date:"Y-m-d" {% templatetag closevariable %}" pubdate>
                {% templatetag openvariable %} object.pub_date|date:"N j, Y" {% templatetag closevariable %}
            </time>
        </p>
    </header>
    <section name="graphic" class="graphic"></section>
    <section name="credits">
        {% templatetag openblock %} if object.extra.sources {% templatetag closeblock %}
            <p class="sources">Sources: {% templatetag openvariable %} object.extra.sources|safe {% templatetag closevariable %}</p>
        {% templatetag openblock %} endif {% templatetag closeblock %}
        {% templatetag openblock %} if object.extra.credits {% templatetag closeblock %}
            <p class="credits">Credits: {% templatetag openvariable %} object.extra.credits|safe {% templatetag closevariable %}</p>
        {% templatetag openblock %} endif {% templatetag closeblock %}
    </section>
</article>
{% templatetag openblock %} endblock {% templatetag closeblock %}
