{% templatetag openblock %} extends "bigbuild/base.html" {% templatetag closeblock %}

{% templatetag openblock %} block container {% templatetag closeblock %}
<article class="container">
    <div class="row">
        <div class="span12"></div>
    </div>
</article>
{% templatetag openblock %} endblock {% templatetag closeblock %}
